summaryrefslogtreecommitdiffstats
path: root/tdeui/kcolordialog.h
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2013-03-02 15:57:34 -0600
committerDarrell Anderson <humanreadable@yahoo.com>2013-03-02 15:57:34 -0600
commit7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f (patch)
treec76702a7f6310fbe9d437e347535422e836e94e9 /tdeui/kcolordialog.h
parenta2a38be7600e2a2c2b49c66902d912ca036a2c0f (diff)
parent27bbee9a5f9dcda53d8eb23863ee670ad1360e41 (diff)
downloadtdelibs-7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f.tar.gz
tdelibs-7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f.zip
Merge branch 'master' of http://scm.trinitydesktop.org/scm/git/tdelibs
Diffstat (limited to 'tdeui/kcolordialog.h')
-rw-r--r--tdeui/kcolordialog.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdeui/kcolordialog.h b/tdeui/kcolordialog.h
index 20c9f799d..e580ad582 100644
--- a/tdeui/kcolordialog.h
+++ b/tdeui/kcolordialog.h
@@ -35,11 +35,11 @@
#include <tqpixmap.h>
#include <tqgridview.h>
-#include "kselect.h"
+#include "tdeselect.h"
class TQComboBox;
class TQLineEdit;
-class KListBox;
+class TDEListBox;
class KPalette;
class KColorCells;
@@ -99,7 +99,7 @@ class KValueSelectorPrivate;
* @see KHSSelector, KColorDialog
* @author Martin Jones (mjones@kde.org)
*/
-class TDEUI_EXPORT KValueSelector : public KSelector
+class TDEUI_EXPORT KValueSelector : public TDESelector
{
Q_OBJECT
@@ -132,7 +132,7 @@ protected:
virtual void resizeEvent( TQResizeEvent * );
/**
* Reimplemented from KSelector. The drawing is
* buffered in a pixmap here. As real drawing
* routine, drawPalette() is used.
*/
@@ -229,7 +229,7 @@ protected:
TQComboBox *combo;
KColorCells *cells;
TQScrollView *sv;
- KListBox *mNamedColorList;
+ TDEListBox *mNamedColorList;
KPalette *mPalette;
int mMinWidth;
int mCols;
@@ -132,7 +132,7 @@ protected:
virtual void resizeEvent( TQResizeEvent * );
/**
- * Reimplemented from KSelector. The drawing is
+ * Reimplemented from TDESelector. The drawing is
* buffered in a pixmap here. As real drawing
* routine, drawPalette() is used.